Implementation of Weighted Higher Order Multivariate Markov Chains (Markov Models)`
======================================i===========================================

This package contains Markov Models implmentation in Python. You will see 3 implementations
1. NaiveMarkov -is the higher order Markov Model
2. Weighted Higher Order Markov Model
3. Weighted Higher Order Multivariate Markov Model as given in the following paper.

Higher-order multivariate Markov chains and their applications; Wai-Ki Ching , Michael K.Ng , Eric S.Fungb, 2008
=>Implementationa and usage example shown here
`
A multivariate Markov chain model for categorical data sequences and its applications in demand predictions Wai‐Ki Ching Eric S. Fung Michael K. Ng

Higher-Order Markov Chain Models for Categorical Data Sequences* Wai Ki Ching, Eric S. Fung, Michael K. Ng [Implemented here as WeightedMarkov]

Application of Markov Chains to Analyze and Predict the Time Series (This paper is numerous bugs and I would avaoid it)

==================
See the example Notebooks for usage



